/*
	projShadows.frag - fragment shader for shadow mapping
	
	texture_map - standard u,v map for object you're drawing
	glow_map	- map that specifies amount of glow at each texture location
	depth_map	- depth buffer from rendering scene from light's perspective
	
	use_glow	- are we actually using a glow map?
	use_shadow	- enable shadowing?
	
	diffuse, ambient, lightDir, halfVector, normal
		- standard lighting variables passed from vertex shader for per pixel lighting

	The lighting part of this shader was lifted from LightHouse3D's tutorial
	http://www.lighthouse3d.com/opengl/glsl/index.php?dirlightpix
	
	It's specifically the shadow mapping stuff that is relevent for this shader

*/

uniform sampler2D texture_map;
uniform sampler2D shadow_map;
uniform float shadowOpacity;

varying vec4 diffuse, ambient;
varying vec3 lightDir, halfVector, normal;

void main() {

	vec4 samp	     = texture2D(texture_map, gl_TexCoord[0].xy);
	
	vec2 coord = clamp(gl_TexCoord[1].xy, 0.0, 1.0);
	float shadow	 = shadowOpacity * texture2D(shadow_map, coord).r + (1.0 - shadowOpacity);

	vec3 n, halfV;
	float NdotL, NdotHV;
	
	vec4 color = ambient;
	n = normalize(normal);
	
	NdotL = max(dot(n, lightDir), 0.0);
	
	color += diffuse * NdotL * shadow;
	halfV = normalize(halfVector);
	NdotHV = max(dot(n, halfV), 0.0);
	color += gl_FrontMaterial.specular * gl_LightSource[0].specular * pow(NdotHV, gl_FrontMaterial.shininess) * shadow;
	
	gl_FragColor = color * samp;
	
}